summaryrefslogtreecommitdiffstats
path: root/khtml/khtml_part.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:57:02 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:57:02 -0600
commita51cd9949c4e6c726a84a61de3cfadd30cefb5c7 (patch)
treea65321bcfdb90583bcc7ef3a90fa357f6632e54c /khtml/khtml_part.cpp
parent984c25aa6969e55896e9a13c8e7f7b8a58991a4e (diff)
downloadtdelibs-a51cd9949c4e6c726a84a61de3cfadd30cefb5c7.tar.gz
tdelibs-a51cd9949c4e6c726a84a61de3cfadd30cefb5c7.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'khtml/khtml_part.cpp')
-rw-r--r--khtml/khtml_part.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/khtml_part.cpp b/khtml/khtml_part.cpp
index c41811f59..28a31ad9e 100644
--- a/khtml/khtml_part.cpp
+++ b/khtml/khtml_part.cpp
@@ -2286,7 +2286,7 @@ void KHTMLPart::checkCompleted()
}
// the view will emit completed on our behalf,
// either now or at next tqrepaint if one is pending
//kdDebug(6050) << this << " asks the view to emit completed. pendingAction=" << pendingAction << endl;
d->m_view->complete( pendingAction );
@@ -6877,7 +6877,7 @@ void KHTMLPart::slotActiveFrameChanged( KParts::Part *part )
if (frame->frameStyle() != TQFrame::NoFrame)
{
frame->setFrameStyle( TQFrame::StyledPanel | TQFrame::Sunken);
- frame->tqrepaint();
+ frame->repaint();
}
}
@@ -6905,7 +6905,7 @@ void KHTMLPart::slotActiveFrameChanged( KParts::Part *part )
if (frame->frameStyle() != TQFrame::NoFrame)
{
frame->setFrameStyle( TQFrame::StyledPanel | TQFrame::Plain);
- frame->tqrepaint();
+ frame->repaint();
}
kdDebug(6050) << "new active frame " << d->m_activeFrame << endl;
}
@@ -2286,7 +2286,7 @@ void KHTMLPart::checkCompleted()
}
// the view will emit completed on our behalf,
- // either now or at next tqrepaint if one is pending
+ // either now or at next repaint if one is pending
//kdDebug(6050) << this << " asks the view to emit completed. pendingAction=" << pendingAction << endl;
d->m_view->complete( pendingAction );